159,307 Commits over 4,566 Days - 1.45cph!
Merge from mixingcooking_ui
privilegecache.enabled convar set to non-admin so we can enable it on the client via the steam launch args
Mixing table UI now only reorders recipe list when availability changes, fixes 4 UI layout changes a second.
Remove previous LINQ usage, saves some allocs.
Dont allow player to use pt boat whilst restrained
Fixed downloaded workshop skin icons keeping a readable CPU copy, similar to
167894
Was around ~20MB RAM in-game for 15 icons
▆ ▇▉▌ ▌▇▇█▇ ▄█▄▊▊ █▅ ▋██▇▍▄ ▆▆▆ ▇▆█▍▅▍▋▋
Fixed every maskable graphic keeping its own corner scratch array
Drops ~11MB of managed memory for 141k graphics
Ignore water hits on cannons, only play water splash instead of the full explosion.
merge from cannonball_ignore_waterhits
Fixed every TMP text keeping its own copy of the constant k_Power rounding table
Drops 5MB of managed memory for 28k texts
Fixed selection history editor window repainting constantly
▄ ▆▍▆ ▌▆█▌▉ ▊▊▌▇ ▉▋ ▌▋▆▉▇▌ █▄▇▆█▊ ▆▇▅▉▉▆ ▌▄▊▊▉▋▌
Move headers inline per-section
Attempt 2 at fixing compute kernel lookup errors during builds
Perform BRG culling in a job
▅ ▆▄▊▅█▌ ▇█▇▅▊▊▋▌▆▉ ▋▅▌▊▆▅█▉█▍▋ ▊█▆
Fix terrain not rendering when instancing is active
merge from PlagueHazmat_Improvements
wip procedural animation-target skin constraint
Add toggle buttons per source, so you can toggle mixing table entries on/off for cooking workbench, etc.
Search still searches across all categories, hidden or not.
Pooling fixes.
Layout tweaks.
Store entity ID for position ticks in a 1000 sized cache
- reduces entity ID from 8 -> 5 -> 2 bytes (8 now, would be ~5 with VarInt encoding, 2 bytes with index lookup)
- also compresses the parent's network ID when parented
- overkill just for network IDs but basically free since we also want to do lossy compression for positions
- demos store the network ID lookup in the keyframes so it can skip forwards & backwards still
- make batch position packets ordered now (not a big deal since they are way smaller than old ones and max one per server frame)
Don't poll all 100+ keys if unity tells us that no key is pressed
Saves 0.04ms/frame
▄ ▌▌▋▍▇▆▄ ▍▆▄▉▉ ▄█▉▄▌▅▇ █▉█▌▋█▉ ▍▇▍▄▅▆▌▉▄ ▌▍▊▌ ▆█▅ ▋▅▆ ▉▋▉▅▊
Terrain diffuse base pyramid disable
▇▊▅█▄▋ ▇▉▉▆▍▍▍▇▋▊█▄▌▄▍▌▉▄▊▇▄▅▇▄▍▆▌▉▋▉▋█▋▊▋▇▌█▇▉▋▊█▊▇▉█▋▆ █▄▅▋▊▋▆▅▉ ▆▊▅█ ▉▅▍▍▇▆ ▆▊ ▄▄▊▅▉█
Merge from Animal_Jumping
Fixed picking up mushrooms not showing the total owned in the pickup notice
merge from optimize_upkeep_multiplier -> main
Cherrypicked
168066 "Can't use the frankenstein table if building blocked"
Can't use the frankenstein table if building blocked
merge from frankensteintable_priv
Basic setup for viewmodel animations when attaching grenades to surfaces for the grenades which have an attach anim asset
▄ ▄▋▌▉▆ ▍█▄▋▄▉▋▄▇ ▅▇▊▉█▇▍▉ ▌█▊▋ ▋▄▇▉▅▍ ▆▉▄▋▆▊▌▉▄ ▍▅ ▄▍▋█▆▅▍▅
merge from cliffs_heightcollider_fix
Fixed some traincar variants not playing any SFX when destroyed/gibbed
simplified meshes on a lot of scrap king building components to accomodate revised textures, fixed lod0>lod1 mismatches across a bunch, fixed culling on corners
Strip AI cover and move points from the client, they're only used by the server
Had 13k of them
Fixed cliffs not stripping their Add_To_Height heightmap mesh collider when loading from a cached map
I had ~6500 of these enabled on a proc gen map
▍ ▅▌▄ █▊▌▍▋ ▌▅█▅▄█ ▇▄▌▌▍▋▇▍ █▌▆▉▄▉▊▉▄ ▅▉▅▌█▌ ▄█▌▉ █▄▋▅▉▍▊ ▉▌▍▅▌█▊▆█ ▆▅▅▌
▅▊▋█▅▆ ▋▌▇▉▊ ▇█▆▆▌▌▉▌▄ ▍█▌▌▇▅▉▊ ▊▊▆▉ ▊▊▉▆▊▇▍ ▄ ▆▉▍▍▋█ ▆█▅
Remove leftover log in RotaryGunCylinderViewmodelComponent
Ballista and static ballista 8 -> 2
Battering ram and catapult seats 8 ->